@@ -1,4 +1,3 @@
-/* $assl: nbclient.c,v 1.5 2011/03/18 22:16:49 marco Exp $ */
 /*
  * Copyright (c) 2009 Marco Peereboom <marco@peereboom.us>
  *
@@ -15,6 +14,9 @@
  * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
+#include <errno.h>
+#include <poll.h>
+
 #include "assl.h"
 
 #define USE_MEM_CERTS
